from setuptools import setup, find_packages

setup(
    name="area-codersao",      # must be unique on PyPI
    version="0.1",
    packages=find_packages(),
    description="A simple library to calculate area of shapes",
    author="Jatin Ghoyal",
    author_email="codersao@gmail.com",
)
